@@ -31,6 +31,18 @@ getLRT.lm <- function(largeModel, smallModel){
 }
 
 
+as.data.frame.PBmodcomp <- function(x, ...){
+    out <- x$test
+    attributes(out) <- c(attributes(out), x[-1])
+    out
+}
+
+as.data.frame.summaryPB <- function(x, ...){
+    out <- x$test
+    attributes(out) <- c(attributes(out), x[-1])
+    out
+}
+
 
 
 
